@@ -2,11 +2,19 @@ import { connect } from 'react-redux';
 import { Map as ImmutableMap } from 'immutable';
 import * as _ from 'lodash-es';
 
+import { FLAGS } from '@console/shared/src/constants';
+import { isModelFeatureFlag } from '@console/plugin-sdk/src/typings';
+import {
+  subscribeToExtensions,
+  extensionDiffListener,
+} from '@console/plugin-sdk/src/api/subscribeToExtensions';
 import {
   ChargebackReportModel,
+  ClusterAutoscalerModel,
   ClusterServiceClassModel,
   ConsoleCLIDownloadModel,
   ConsoleExternalLogLinkModel,
+  ConsoleLinkModel,
   ConsoleNotificationModel,
   ConsoleYAMLSampleModel,
   MachineAutoscalerModel,
@@ -15,12 +23,15 @@ import {
   MachineModel,
   PrometheusModel,
 } from '../models';
-import { referenceForModel } from '../module/k8s';
+import { referenceForModel, referenceForGroupVersionKind } from '../module/k8s';
 import { RootState } from '../redux';
 import { ActionType as K8sActionType } from '../actions/k8s';
 import { FeatureAction, ActionType } from '../actions/features';
-import { FLAGS } from '@console/shared/src/constants';
-import * as plugins from '../plugins';
+import { pluginStore } from '../plugins';
+import {
+  ModelFeatureFlag as DynamicModelFeatureFlag,
+  isModelFeatureFlag as isDynamicModelFeatureFlag,
+} from '@console/dynamic-plugin-sdk/src/extensions/feature-flags';
 
 export const defaults = _.mapValues(FLAGS, (flag) =>
   flag === FLAGS.AUTH_ENABLED ? !window.SERVER_FLAGS.authDisabled : undefined,
@@ -28,7 +39,9 @@ export const defaults = _.mapValues(FLAGS, (flag) =>
 
 export const baseCRDs = {
   [referenceForModel(ChargebackReportModel)]: FLAGS.CHARGEBACK,
+  [referenceForModel(ClusterAutoscalerModel)]: FLAGS.CLUSTER_AUTOSCALER,
   [referenceForModel(ClusterServiceClassModel)]: FLAGS.SERVICE_CATALOG,
+  [referenceForModel(ConsoleLinkModel)]: FLAGS.CONSOLE_LINK,
   [referenceForModel(ConsoleCLIDownloadModel)]: FLAGS.CONSOLE_CLI_DOWNLOAD,
   [referenceForModel(ConsoleExternalLogLinkModel)]: FLAGS.CONSOLE_EXTERNAL_LOG_LINK,
   [referenceForModel(ConsoleNotificationModel)]: FLAGS.CONSOLE_NOTIFICATION,
@@ -42,12 +55,38 @@ export const baseCRDs = {
 
 const CRDs = { ...baseCRDs };
 
-plugins.registry.getModelFeatureFlags().forEach((ff) => {
-  const modelRef = referenceForModel(ff.properties.model);
-  if (!CRDs[modelRef]) {
-    CRDs[modelRef] = ff.properties.flag as FLAGS;
+const addToCRDs = (ref: string, flag: string) => {
+  if (!CRDs[ref]) {
+    CRDs[ref] = flag as FLAGS;
   }
-});
+};
+
+pluginStore
+  .getAllExtensions()
+  .filter(isModelFeatureFlag)
+  .forEach((ff) => {
+    addToCRDs(referenceForModel(ff.properties.model), ff.properties.flag);
+  });
+
+subscribeToExtensions<DynamicModelFeatureFlag>(
+  extensionDiffListener((added, removed) => {
+    const getModelRef = (e: DynamicModelFeatureFlag) => {
+      const model = e.properties.model;
+      return referenceForGroupVersionKind(model.group)(model.version)(model.kind);
+    };
+
+    added.forEach((e) => {
+      addToCRDs(getModelRef(e), e.properties.flag);
+    });
+
+    removed.forEach((e) => {
+      delete CRDs[getModelRef(e)];
+    });
+
+    // TODO(vojtech): change of 'CRDs' should trigger relevant detection logic
+  }),
+  isDynamicModelFeatureFlag,
+);
 
 export type FeatureState = ImmutableMap<string, boolean>;
 
